==> apache-bigtop-manager-1.0.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/en_US/overview.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export default {
  basic_info: 'Basic Information',
  service_info: 'Service Information',
  detail: 'Details',
  cluster_status: 'Status',
  cluster_name: 'Name',
  cluster_desc: 'Description',
  host_count: 'Host Count',
  service_count: 'Service Count',
  memory: 'Memory',
  chart: 'Chart',
  core_count: 'Core Count',
  disk_size: 'Disk Size',
  creator: 'Creator',
  memory_usage: 'Memory Usage',
  cpu_usage: 'Cpu Usage',
  unit_host: 'Hosts',
  unit_service: 'Services',
  unit_core: 'Cores',
  unit_component: 'Components',
  component_info: 'Component Information',
  host_status: 'Status',
  hostname: 'Name',
  host_desc: 'Description',
  component_count: 'Component Count',
  os: 'OS',
  ip_v4: 'IPv4',
  ip_v6: 'IPv6',
  arch: 'Architecture',
  service_status: 'Status',
  service_name: 'Name',
  service_version: 'Version',
  metrics: 'Metrics',
  kerberos: 'Kerberos'
}

==> apache-bigtop-manager-1.1.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/en_US/overview.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export default {
  basic_info: 'Basic Information',
  service_info: 'Service Information',
  detail: 'Details',
  cluster_status: 'Status',
  cluster_name: 'Name',
  cluster_desc: 'Description',
  host_count: 'Host Count',
  service_count: 'Service Count',
  memory: 'Memory',
  chart: 'Chart',
  core_count: 'Core Count',
  disk_size: 'Disk Size',
  creator: 'Creator',
  memory_usage: 'Memory Usage',
  cpu_usage: 'Cpu Usage',
  unit_host: 'Hosts',
  unit_service: 'Services',
  unit_core: 'Cores',
  unit_component: 'Components',
  component_info: 'Component Information',
  host_status: 'Status',
  hostname: 'Name',
  host_desc: 'Description',
  component_count: 'Component Count',
  os: 'OS',
  ip_v4: 'IPv4',
  ip_v6: 'IPv6',
  arch: 'Architecture',
  service_status: 'Status',
  service_name: 'Name',
  service_version: 'Version',
  metrics: 'Metrics',
  kerberos: 'Kerberos',
  system_load: 'System Load',
  disk_io: 'Disk I/O'
}
